==> galileo-1.9.0.tar.gz: galileo-1.9.0/src/galileo/resources/api/datasets/get_dataset_synthetic_extend_status_datasets_extend_dataset_id_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.job_progress import JobProgress
from ...types import Response


def _get_kwargs(dataset_id: str) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {"method": "get", "url": f"/datasets/extend/{dataset_id}"}

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[HTTPValidationError, JobProgress]]:
    if response.status_code == 200:
        response_200 = JobProgress.from_dict(response.json())

        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[HTTPValidationError, JobProgress]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(dataset_id: str, *, client: AuthenticatedClient) -> Response[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, JobProgress]]
    """

    kwargs = _get_kwargs(dataset_id=dataset_id)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(dataset_id: str, *, client: AuthenticatedClient) -> Optional[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, JobProgress]
    """

    return sync_detailed(dataset_id=dataset_id, client=client).parsed


async def asyncio_detailed(
    dataset_id: str, *, client: AuthenticatedClient
) -> Response[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, JobProgress]]
    """

    kwargs = _get_kwargs(dataset_id=dataset_id)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(dataset_id: str, *, client: AuthenticatedClient) -> Optional[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, JobProgress]
    """

    return (await asyncio_detailed(dataset_id=dataset_id, client=client)).parsed

==> galileo-1.26.0.tar.gz: galileo-1.26.0/src/galileo/resources/api/datasets/get_dataset_synthetic_extend_status_datasets_extend_dataset_id_get.py <==
from http import HTTPStatus
from typing import Any, Optional, Union

import httpx

from galileo.utils.headers_data import get_package_version
from galileo_core.constants.request_method import RequestMethod
from galileo_core.helpers.api_client import ApiClient

from ... import errors
from ...models.http_validation_error import HTTPValidationError
from ...models.job_progress import JobProgress
from ...types import Response


def _get_kwargs(dataset_id: str) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": RequestMethod.GET,
        "return_raw_response": True,
        "path": f"/datasets/extend/{dataset_id}",
    }

    headers["X-Galileo-SDK"] = f"galileo-python/{get_package_version()}"

    _kwargs["content_headers"] = headers
    return _kwargs


def _parse_response(
    *, client: ApiClient, response: httpx.Response
) -> Optional[Union[HTTPValidationError, JobProgress]]:
    if response.status_code == 200:
        return JobProgress.from_dict(response.json())

    if response.status_code == 422:
        return HTTPValidationError.from_dict(response.json())

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    return None


def _build_response(
    *, client: ApiClient, response: httpx.Response
) -> Response[Union[HTTPValidationError, JobProgress]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(dataset_id: str, *, client: ApiClient) -> Response[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, JobProgress]]
    """

    kwargs = _get_kwargs(dataset_id=dataset_id)

    response = client.request(**kwargs)

    return _build_response(client=client, response=response)


def sync(dataset_id: str, *, client: ApiClient) -> Optional[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, JobProgress]
    """

    return sync_detailed(dataset_id=dataset_id, client=client).parsed


async def asyncio_detailed(dataset_id: str, *, client: ApiClient) -> Response[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[HTTPValidationError, JobProgress]]
    """

    kwargs = _get_kwargs(dataset_id=dataset_id)

    response = await client.arequest(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(dataset_id: str, *, client: ApiClient) -> Optional[Union[HTTPValidationError, JobProgress]]:
    """Get Dataset Synthetic Extend Status

    Args:
        dataset_id (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[HTTPValidationError, JobProgress]
    """

    return (await asyncio_detailed(dataset_id=dataset_id, client=client)).parsed
